@@ -45,21 +45,34 @@ Known Issues:
        has spaces -- if we use ~ the build command will fail.
 '''
 
-from optparse import OptionParser, OptionGroup #note: deprecated in Python27, use argparse
 from mozrunner import Runner, FirefoxRunner
-import simplejson, urllib
-import ximport
-from types import *
-from utils import hgId, captureStdout, increment_day
-import os, sys, subprocess, string, re, tempfile, shlex, glob, shutil, datetime, multiprocessing
+from optparse import OptionParser, OptionGroup
 from time import gmtime, strftime
+from types import *
+from utils import hgId, captureStdout, increment_day, cpuCount
+import datetime
+import glob
+import multiprocessing
+import os
+import re
+import shlex
+import shutil
+import simplejson
+import string
+import subprocess
+import sys
+import tempfile
+import urllib
+import ximport
 
 #Global Variables
 showMakeData = 0
-progVersion="0.4.5"
+progVersion="0.4.6"
 
 class Builder():
-    def __init__(self, makeCommand=["make","-f","client.mk","build"] , shellCacheDir=os.path.join(os.path.expanduser("~"), "moz-commitbuilder-cache"), cores=1, repoURL="http://hg.mozilla.org/mozilla-central",clean=False, mozconf=None):
+    def __init__(self, makeCommand=["make","-f","client.mk","build"] , shellCacheDir=os.path.join(os.path.expanduser("~"),
+                 "moz-commitbuilder-cache"), cores=1, repoURL="http://hg.mozilla.org/mozilla-central",clean=False,
+                 mozconf=None):
         #Set variables that we need
         self.makeCommand = makeCommand
         self.shellCacheDir = shellCacheDir
@@ -246,6 +259,7 @@ class Builder():
 
         else:
             print "Invalid values. Please check your changeset revision numbers."
+            print "If the problem persists, try running mozcommitbuilder with the -f flag."
 
 
     def check_done(self, doneString):
@@ -421,11 +435,7 @@ class Builder():
             return False
         return True
 
-def cpuCount():
-    try:
-        return multiprocessing.cpu_count()
-    except NotImplementedError:
-        return 1
+
 
 def cli():
     #Command line interface
@@ -477,7 +487,7 @@ def cli():
     group4.add_option("-q", "--revision", dest="revision", default=None, metavar="[changeset]",
                                         help="revision number for single changeset to build binary from")
 
-    group5 = OptionGroup(parser, "Automatic Testing Options (EXPERIMENTAL)",
+    group5 = OptionGroup(parser, "Automatic Testing Options",
                                         "Options for using an automated test instead of interactive prompting for bisection. " \
                                         "Please read documentation on how to write testing functions for this script.")
 
@@ -522,19 +532,13 @@ def cli():
         commitBuilder.cores = options.cores
         commitBuilder.mozconfigure()
 
-    # TODO: Allow a user to build a binary from cli
-    if options.binary:
-        pass
-        #if options.revision:
-        #    pass
-        #else:
-        #    print "You need to specify a revision to build the binary from."
-
     # For building single commits:
     if options.single:
         if options.run:
             commitBuilder.buildAndRun(changeset=options.single)
             print "Firefox successfully built and ran!"
+        elif options.binary:
+            commitBuilder.getBinary(revision=options.single)
         else:
             commitBuilder.build(changeset=options.single)
             print "Local trunk built. Not running."
