@@ -41,6 +41,13 @@ import datetime
 import platform
 import os
 import subprocess
+import multiprocessing
+
+def cpuCount():
+    try:
+        return multiprocessing.cpu_count()
+    except NotImplementedError:
+        return 1
 
 def increment_day(date):
     #TODO: MOVE TO UTILS. Increments a date string.
@@ -51,7 +58,7 @@ def increment_day(date):
 
 #Resolves names like "tip" and "52707" to the long stable hg hash ids
 def hgId(rev, hgPrefix):
-    return captureStdout(hgPrefix + ["id", "-i", "-r", rev],ignoreExitCode=True)
+    return captureStdout(hgPrefix + ["id", "-i", "-r", rev],ignoreExitCode=True, ignoreStderr=True)
 
 #Captures command line output into python string
 def captureStdout(cmd, ignoreStderr=False, combineStderr=False, ignoreExitCode=False, currWorkingDir=os.getcwdu()):
